==> apache-qpid-broker-j-7.1.12-src.tar.gz: apache-qpid-broker-j-7.1.12-src/systests/protocol-tests-amqp-0-8/src/main/java/org/apache/qpid/tests/protocol/v0_8/PerformativeResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.qpid.tests.protocol.v0_8;

import org.apache.qpid.server.protocol.v0_8.transport.AMQBody;
import org.apache.qpid.server.protocol.v0_8.transport.AMQFrame;
import org.apache.qpid.tests.protocol.Response;

public class PerformativeResponse implements Response<AMQBody>
{
    private final int _channel;
    private final long _size;
    private final AMQBody _body;

    public PerformativeResponse(int channel, long size, final AMQBody body)
    {
        _channel = channel;
        _size = size;
        _body = body;
    }

    @Override
    public AMQBody getBody()
    {
        return _body;
    }

    @Override
    public String toString()
    {
        return "PerformativeResponse{" +
               "_channel=" + _channel +
               ", _size=" + _size +
               ", _body=" + _body +
               '}';
    }
}

==> apache-qpid-broker-j-10.0.0-src.tar.gz: apache-qpid-broker-j-10.0.0-src/systests/protocol-tests-amqp-1-0/src/main/java/org/apache/qpid/tests/protocol/v1_0/PerformativeResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.qpid.tests.protocol.v1_0;

import org.apache.qpid.server.protocol.v1_0.type.FrameBody;
import org.apache.qpid.tests.protocol.Response;

public class PerformativeResponse implements Response<FrameBody>
{
    private final short _channelId;
    private final FrameBody _frameBody;

    public PerformativeResponse(final short channelId,
                                final FrameBody frameBody)
    {
        _channelId = channelId;
        _frameBody = frameBody;
    }

    @Override
    public FrameBody getBody()
    {
        return _frameBody;
    }


    public short getChannelId()
    {
        return _channelId;
    }

    @Override
    public String toString()
    {
        return "PerformativeResponse{" +
               "_channelId=" + _channelId +
               ", _frameBody=" + _frameBody +
               '}';
    }
}
